# Set a conventional commit style topic

fix(validate): what was fixed
feat: what new feature was added
feat(data-product)!: what breaking change was made

# Replace this description with additional information to be included in merge commit

[Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/)

```
[optional body]

[optional footer(s)]
BREAKING CHANGE: details of change
Refs: NEOS-1234
```
